django_auxilium.utils.functools.decorators module
=================================================

.. automodule:: django_auxilium.utils.functools.decorators
    :members:
    :undoc-members:
    :show-inheritance:
